@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION @ISA %EXPORT_TAGS @EXPORT @EXPORT_OK);
-$VERSION = '5.04';
+$VERSION = '5.05';
 
 =head1 NAME
 
@@ -188,7 +188,7 @@ sub StockSelect {
         $html .= ' selected="selected"' if($opt == $_);
         $html .= ">$stock{$_}->{title}</option>";
     }
-    $html .= "</select>\n";
+    $html .= "</select>";
 
     return $html;
 }
